@@ -396,7 +396,7 @@ sub parse_io_option ($$$$) {
 
 =head2 finish_one_io_option
 
-    $fsdb_io = $filter->finish_one_io_option($io_direction, $token, @fsdb_args);
+    $fsdb_io = $filter->finish_io_option($io_direction, $token, @fsdb_args);
 
 This helper function 
 finishes setting up a Fsdb::IO object in $IO_DIRECTION,
