@@ -2,7 +2,7 @@
 
 #
 # dbjoin.pm
-# Copyright (C) 1991-2024 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1991-2022 by John Heidemann <johnh@isi.edu>
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -118,10 +118,6 @@ Default: inner.
 
 Select join method (algorithm).
 Choices are merge, righthash, and lefthash.
-With hashs, that side is cached.
-(Warning: the lefthas method is about caching the left input,
-and it does I<not> imply a left-type join,
-which keeps even unmatched left keys.)
 Default: merge.
 
 =item B<-S> or B<--pre-sorted>
@@ -384,7 +380,7 @@ sub setup($) {
 	$self->finish_io_option('inputs', -comment_handler => $self->create_delay_comments_sub);
     };
 
-    # can't move next check earlier; it must be after "finish_io_option".
+    # can't move next check earlier; it must be fater "finish_io_option".
     croak($self->{_prog} . ": cannot handle input data with different field separators.\n")
 	if (!defined($self->{_ins}[0]->compare($self->{_ins}[1])));
 
@@ -394,7 +390,7 @@ sub setup($) {
     my $i = 0;  # counts output columns
     my %join_keys;
     my $key;
-    my @output_colspecs;
+    my @output_columns;
     my %all_keys;
     my @copy_codes = ('', '');
     my $build_key_from_hashside_code = '';
@@ -403,18 +399,16 @@ sub setup($) {
     my $build_output_from_hit_code = '';
     my $merge_output_from_hit_code = '';
     my $build_output_from_full_code = '';
-    my @hash_input_col_to_hit_col;   # not actually used
+    my @hash_input_col_to_hit_col;   # not actullay used
     my $hit_ncol = 0;
     for $key (@{$self->{_sort_argv}}) {
         next if ($key =~ /^-/);   # we deal with this later
 
 	# figure out details for both sides
 	my @col_i;
-        my @colspec_i;
 	foreach (0..1) {
 	    $col_i[$_] = $self->{_ins}[$_]->col_to_i($key);
-            $colspec_i[$_] = $self->{_ins}[$_]->col_to_colspec($col_i[$_]);
-            croak($self->{_prog} . ": column ``$key'' is not in " . ($_ == 0 ? "left" : "right") ." join source.\n") if (!defined($col_i[$_]));
+	    croak($self->{_prog} . ": column ``$key'' is not in " . ($_ == 0 ? "left" : "right") ." join source.\n") if (!defined($col_i[$_]));
 	    # for merge join, details are copy
 	    $copy_codes[$_] .= '$out_fref->[' . $i . '] = $frefs[' . $_ . "]->[$col_i[$_]];\n";
 	    # for hash join, also build the hash key
@@ -431,10 +425,8 @@ sub setup($) {
 		};
 	    };
 	};
-        # xxx: could allow type coercion in some cases.
-        croak($self->{_prog} . ": column ``$key'' has differing colspecs: $colspec_i[0] and $colspec_i[1].\n") if ($colspec_i[0] ne $colspec_i[1]);
 
-	push(@output_colspecs, $colspec_i[0]);
+	push(@output_columns, $key);
         $join_keys{$key} = $i;
         $all_keys{$key} = $i;
         $i++;
@@ -445,13 +437,11 @@ sub setup($) {
     #
     my $copy_codes = '';
     my $col_i;
-    my $colspec;
     foreach $key (@{$self->{_ins}[0]->cols}) {
         next if (defined($all_keys{$key}));  # already got it
+	push(@output_columns, $key);
 	$col_i = $self->{_ins}[0]->col_to_i($key);
 	defined($col_i) or croak("assert");
-        $colspec = $self->{_ins}[0]->col_to_colspec($col_i);
-	push(@output_colspecs, $colspec);
 	$copy_codes[0] .= '$out_fref->[' . $i . '] = $frefs[0]->[' . $col_i . '];' . "\n";
 	$all_keys{$key} = $i;
 	if ($self->{_join_method} ne 'merge') {
@@ -476,10 +466,9 @@ sub setup($) {
         if (defined($all_keys{$key})) {
 	    croak($self->{_prog} . ": column $key is in both of the joined files, but is not joined upon.\nAll non-joined columns must be unique.\nBefore joining you must\nrename one of the source columns\nor remove one of the duplicate input columns.\n");
         };
+	push(@output_columns, $key);
 	$col_i = $self->{_ins}[1]->col_to_i($key);
 	defined($col_i) or croak("assert");
-        $colspec = $self->{_ins}[1]->col_to_colspec($col_i);
-	push(@output_colspecs, $colspec);
 	$copy_codes[1] .= '$out_fref->[' . $i . '] = $frefs[1]->[' . $col_i . '];' . "\n";
 	$all_keys{$key} = $i;
 	if ($self->{_join_method} ne 'merge') {
@@ -505,7 +494,7 @@ sub setup($) {
     $self->{_merge_output_from_hit_code} = $merge_output_from_hit_code;
     $self->{_build_output_from_full_code} = $build_output_from_full_code;
 
-    $self->finish_io_option('output', -clone => $self->{_ins}[0], -cols => \@output_colspecs);
+    $self->finish_io_option('output', -clone => $self->{_ins}[0], -cols => \@output_columns);
 
     #
     # comparision code
