@@ -252,7 +252,6 @@ sub set_defaults ($) {
     $self->{_header} = undef;
     $self->{_output_on_no_input} = undef;
     $self->{_fscode} = undef;
-    $self->{_weight_column} = undef;
 }
 
 =head2 parse_options
@@ -289,7 +288,6 @@ sub parse_options ($@) {
 	'q|quantile=i' => \$self->{_quantile},
 	'S|pre-sorted+' => \$self->{_pre_sorted},
 	'T|tmpdir|tempdir=s' => \$self->{_tmpdir},
-	'w|weight=s' => \$self->{_weight_column},
 	) or pod2usage(2);
     $self->parse_target_column(\@argv);
 }
@@ -325,8 +323,6 @@ sub setup ($) {
 	if (defined($self->{_median}));
     push(@dbcolstats_argv, '--quantile', $self->{_quantile})
 	if (defined($self->{_quantile}));
-    push(@dbcolstats_argv, '--weight', $self->{_weight_column})
-	if (defined($self->{_weight_column}));
     push(@dbcolstats_argv, '--tmpdir', $self->{_tmpdir})
 	if (defined($self->{_tmpdir}));
     push(@dbcolstats_argv, '--parallelism', $self->{_max_parallelism})
