@@ -37,8 +37,6 @@ uniquifying field.
 three lines of output with both a's, but if you dbsort it,
 it will become a/a/b and dbrowuniq will output a/b.
 
-(See L<dbcoluniqcount> for a tool that relaxes this adajcency requirement.)
-
 By default, L<dbrowuniq> outputs the I<first> unique row.
 Optionally, with C<-L>, it will output the I<last> unique row,
 or with C<-B> it outputs both first and last.
@@ -50,16 +48,6 @@ Incremental counting, when the C<count> column already exists,
 is possible with C<-I>.
 With incremental counting, the existing count column is summed.
 
-A very common idiom to count number of rows by the category field is:
-
-    dbsort category | dbrowuniq -c category 
-
-When the number of categories is small enough to fit in memory,
-a more efficient (avoiding the sort!) equivalent is
-
-    dbcoluniqcount cateogry
-
-
 =head1 OPTIONS
 
 =over 4
@@ -244,7 +232,7 @@ Incremental counting.
 
 =head1 SEE ALSO
 
-L<Fsdb>, L<dbcoluniqcount>.
+L<Fsdb>.
 
 
 =head1 CLASS FUNCTIONS
