@@ -345,7 +345,7 @@ sub segment_next_output($$) {
 	print "# dbsort segment_next_output: final output\n" if ($self->{_debug});
     } else {
 	# dump to a file for merging
-	my $tmpfile = Fsdb::Support::NamedTmpfile::alloc($self->{_tmpdir}, 1);
+	my $tmpfile = Fsdb::Support::NamedTmpfile::alloc($self->{_tmpdir});
 	$out = $tmpfile;   # just return the name
 	push(@{$self->{_files_to_merge}}, $tmpfile);
 	print "# dbsort segment_next_output: intermediate file: $tmpfile\n" if ($self->{_debug});
@@ -423,8 +423,6 @@ sub segment_merge_start($$) {
 	    if (defined($self->{_header}));
 	push(@merge_args, '-T', $self->{_tmpdir})
 	    if (defined($self->{_tmpdir}));
-        push(@merge_args, '-d')
-            if ($self->{_debug});
 	push(@merge_args, @{$self->{_sort_argv}});
 
 	my($writer, $merge_fred) = dbpipeline_sink(\@writer_args,
