@@ -2,8 +2,7 @@
 
 #
 # yaml_to_db.pm
-# Copyright (C) 2011-2016 by John Heidemann <johnh@isi.edu>
-# $Id: 54d87bcf09ffd487550f0f7e05ab0a77cf2a3670 $
+# Copyright (C) 2011-2018 by John Heidemann <johnh@isi.edu>
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -29,6 +28,8 @@ The input is parsed as YAML,
 assuming the file is an array of dictionary entries.
 We extract the dictionary names and output this as an fsdb table.
 
+We also flatten one level of lists into comma-separated values.
+
 The output is tab-separated fsdb.
 (Someday more general field separators should be supported.)
 
@@ -211,7 +212,7 @@ sub setup($) {
     my $yaml_str = join('', $self->{_in}->getlines);
     my $yaml = $self->{_yaml} = Load($yaml_str);
 
-    croak $self->{_prog} . ": yaml is not in expected format (toplevel list)\n"    
+    croak($self->{_prog} . ": yaml is not in expected format (toplevel list)\n")
         if (ref $yaml ne 'ARRAY');
 
     #
@@ -223,7 +224,7 @@ sub setup($) {
     my %cols_hash;
     my $record_no = 0;
     foreach my $href (@$yaml) {
-        croak $self->{_prog} . ": yaml is not in expected format, record $record_no is not a dictionary\n"
+        croak($self->{_prog} . ": yaml is not in expected format, record $record_no is not a dictionary\n")
 	    if (ref $href ne 'HASH');
 	foreach (sort keys %$href) {
 	    next if (defined($cols_hash{$_}));
@@ -267,7 +268,12 @@ sub run($) {
 	    if (!defined($i)) {
 		warn $self->{_prog} . ": unknown field $_ in record $record_no.\n";
 	    } else {
-		$row[$i] = $href->{$_}; 
+                my $n = $href->{$_};
+                if (ref $n eq 'ARRAY') {
+                    # one level of flattening
+                    $n = "[" . join(',', @$n) . "]";
+                };
+		$row[$i] = $n;
 	    };
 	};
 	grep { s/\t/ /g; } @row;   # clean up for fsdb double-space separator
@@ -280,7 +286,7 @@ sub run($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 2011-2016 by John Heidemann <johnh@isi.edu>
+Copyright (C) 2011-2018 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
