@@ -254,32 +254,12 @@ extension
 sub _find_filename_decompressor($;$) {
     my($file, $as_extension) = @_;
     return undef if (!defined($file));
-    my($ext) = ($file =~ m/\.(gz|xz|bz2|sz)~?$/);
+    my($ext) = ($file =~ m/\.(gz|xz|bz2)$/);
     $ext = $file if ($as_extension && !defined($ext));
     return undef if (!defined($ext));
     return "zcat" if ($ext eq "gz");
     return "xzcat" if ($ext eq "xz");
     return "bzcat" if ($ext eq  "bz2");
-    return "snzcat" if ($ext eq  "sz");
-    return undef;
-}
-
-=head2 _find_filename_compressor
-
-returns the name of the compression program for FILE if it ends in a compression
-extension
-
-=cut
-sub _find_filename_compressor($;$) {
-    my($file, $as_extension) = @_;
-    return undef if (!defined($file));
-    my($ext) = ($file =~ m/\.(gz|xz|bz2|sz)~?$/);
-    $ext = $file if ($as_extension && !defined($ext));
-    return undef if (!defined($ext));
-    return "gzip -c" if ($ext eq "gz");
-    return "xz -c" if ($ext eq "xz");
-    return "bzip2 -c" if ($ext eq  "bz2");
-    return "snzip -c" if ($ext eq  "sz");
     return undef;
 }
 
