@@ -131,24 +131,14 @@ sub config_one {
 	my $fh;
 	my $mode = $self->default_binmode();
 	if ($file eq '-') {
-            $fh = new IO::Handle;
-	    $fh->fdopen(fileno(STDOUT),">");
-	    binmode $fh, $mode;
+	     $fh = new IO::Handle;
+	     $fh->fdopen(fileno(STDOUT),">");
+	     binmode $fh, $mode;
         } elsif ($file =~ /^hdfs:/) {
-            my $hdfs_reader_pid = open($fh, '|-', "hdfs", "-put", "-", $file);
-	    binmode $fh, $mode;
+             my $hdfs_reader_pid = open($fh, '|-', "hdfs", "-put", "-", $file);
+	     binmode $fh, $mode;
 	} else {
-            my $compressor = Fsdb::IO::_find_filename_compressor($file);
-            if ($compressor) {
-                if ($file =~ /^\-\.\w+$/) {
-                    # allow -.gz to gzip to stdout, at least for the test suite
-                    $self->{_compression_pid} = open($fh, '|-', $compressor);
-                } else {
-                    $self->{_compression_pid} = open($fh, '|-', "$compressor > $file");
-                };
-            } else {
-                $fh = new IO::File $file, ">$mode";
-            };
+	     $fh = new IO::File $file, ">$mode";
 	};
 	if ($fh) {
 	    $self->{_fh} = $fh;
