@@ -61,28 +61,8 @@ my %named_tmpfiles;
 my $tmpdir = undef;
 my $template = undef;
 
-my $have_snzip = undef;
-
-=head2 cleanup_one
-
-    Fsdb::Support::NamedTmpfile::alloc($directory, $compression);
-
-Create a new tmpfile in DIRECTORY, optionally with COMPRESSION.
-
-
-=cut
-
-sub alloc(;$$) {
-    my($tmpdir, $compression) = @_;
-
-    my($suffix) = "~";
-    if ($compression) {
-        if (!defined($have_snzip)) {
-            $have_snzip = (-x "/usr/bin/snzip" ? 1 : 0);
-        };
-        # Snzip *requires* a .sz extension or snzip throws an error.
-        $suffix = $have_snzip ? ".sz" : ".gz~";
-   };
+sub alloc {
+    my($tmpdir) = @_;
 
     if (!defined($tmpdir)) {
 	$tmpdir = (defined($ENV{'TMPDIR'}) ? $ENV{'TMPDIR'} : "/tmp") if (!defined($tmpdir));
@@ -93,13 +73,10 @@ sub alloc(;$$) {
 
     croak "tmpdir $tmpdir is not a directory\n" if (! -d $tmpdir);
     croak "tmpdir $tmpdir is not writable\n" if (! -w $tmpdir);
-    my($fh, $fn) = tempfile($template, SUFFIX => $suffix, DIR => $tmpdir);
+    my($fh, $fn) = tempfile($template, SUFFIX => "~", DIR => $tmpdir);
     close $fh;
     {
-        #	lock($named_tmpfiles_lock);
-        # We save the pid of the creator, so only that pid will clean it up.
-        # If we don't do this and fork, then each child will also attempt to cleanup
-        # and tmpfiles will get prematurely reaped.
+#	lock($named_tmpfiles_lock);
 	$named_tmpfiles{$fn} = $$;
     }
 
